@@ -1,12 +1,12 @@
 package SPVM::Sys;
 
-our $VERSION = "0.501";
+our $VERSION = "0.502";
 
 1;
 
 =head1 Name
 
-SPVM::Sys - System Calls for File IO, User, Process, Signal, Socket
+SPVM::Sys - System Calls for File IO, Sockets, Time, Process, Signals, Users
 
 =head1 Description
 
@@ -36,15 +36,35 @@ Methods compatible with file IO, sockets, file paths, current directory, select,
 
 C<static method env : string ($name : string);>
 
-Gets an environment variable. The same as getting of the Perl L<$ENV{$name}|https://perldoc.perl.org/perlvar#%25ENV>.
+Gets an environment variable with the name $name.
+
+=head2 set_env
+
+C<static method set_env : void ($name : string, $value : string);>
+
+Sets an environment variable with the name $name and the value $value.
+
+If $value is undef or "", the environment variable is removed.
+
+Exceptions:
+
+This method calls the following methods, so exceptions thrown by these methods could be thrown.
+
+=over 2
+
+=item * L<_putenv_s|SPVM::Sys::Env/"_putenv_s"> in Sys::Env
+
+=item * L<setenv|SPVM::Sys::Env/"setenv"> in Sys::Env
+
+=item * L<unsetenv|SPVM::Sys::Env/"unsetenv"> in Sys::Env
+
+=back
 
 =head2 osname
 
 C<static method osname : string ()>
 
-Gets OS name. The same as Perl L<$^O|https://perldoc.perl.org/perlvar#$%5EO>.
-
-Currently the following OS names are supported.
+Gets the OS name. This method corresponds to Perl's L<$^O|https://perldoc.perl.org/perlvar#$%5EO>.
 
 =over 2
 
@@ -62,149 +82,343 @@ Currently the following OS names are supported.
 
 =back
 
+Excetpions:
+
+If the OS name could not be determined, an exception is thrown.
+
 =head2 A
 
 C<static method A : double ($file : string);>
 
-Script start time minus file access time, in days. The same as Perl L<-A|https://perldoc.perl.org/functions/-X>.
+Returns script start time minus file access time of the file $file, in days.
+
+This method corresponds to Perl's  L<-A|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
+
+The exceptions thrown by he L</"stat"> method could be thrown.
 
 =head2 C
 
 C<static method C : double ($file : string);>
 
-Script start time minus file inode change time, in days. The same as Perl L<-C|https://perldoc.perl.org/functions/-X>.
+Returns script start time minus file inode change time of the file $file, in days.
+
+This method corresponds to Perl's  L<-C|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
+
+The exceptions thrown by he L</"stat"> method could be thrown.
 
 =head2 M
 
 C<static method M : double ($file : string);>
 
-Script start time minus file modification time, in days. The same as Perl L<-M|https://perldoc.perl.org/functions/-X>.
+Returns script start time minus file modification time of the file $file, in days.
+
+This method corresponds to Perl's  L<-M|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
+
+The exceptions thrown by he L</"stat"> method could be thrown.
 
 =head2 O
 
 C<static method O : int ($file : string);>
 
-File is owned by real uid. The same as Perl L<-O|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Othersize if the file $file is owned by real uid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-O|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 R
 
 C<static method R : int ($file : string);>
 
-File is readable by real uid/gid. The same as Perl L<-R|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is readable by real uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-R|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 S
 
 C<static method S : int ($file : string);>
 
-File is a socket. The same as Perl L<-S|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is a socket, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-S|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 W
 
 C<static method W : int ($file : string);>
 
-File is writable by real uid/gid. The same as Perl L<-W|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is writable by real uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-W|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 X
 
 C<static method X : int ($file : string);>
 
-File is executable by real uid/gid. The same as Perl L<-X|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is executable by real uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-X|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 b
 
 C<static method b : int ($file : string);>
 
-File is a block special file. The same as Perl L<-b|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is a block special file, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-b|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 c
 
 C<static method c : int ($file : string);>
 
-File is a character special file. The same as Perl L<-c|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is a character special file, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-c|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 d
 
 C<static method d : int ($file : string);>
 
-File is a directory. The same as Perl L<-d|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+Otherwise if the file $file is a directory, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-d|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 e
 
 C<static method e : int ($file : string);>
 
-File exists. The same as Perl L<-e|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value. 
+
+This method corresponds to Perl's  L<-e|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 f
 
 C<static method f : int ($file : string);>
 
-File is a plain file. The same as Perl L<-f|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is a plain file, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-f|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 g
 
 C<static method g : int ($file : string);>
 
-File has setgid bit set. The same as Perl L<-g|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file has setgid bit set, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-g|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 k
 
 C<static method k : int ($file : string);>
 
-File has sticky bit set. The same as Perl L<-k|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file has sticky bit set, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-k|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 l
 
 C<static method l : int ($file : string);>
 
-File is a symbolic link (false if symlinks aren't supported by the file system). The same as Perl L<-l|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"lstat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is a symbolic link (false if symlinks aren't supported by the file system), returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-l|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 o
 
 C<static method o : int ($file : string);>
 
-File is owned by effective uid. The same as Perl L<-l|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is owned by effective uid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-l|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 p
 
 C<static method p : int ($file : string);>
 
-File is a named pipe (FIFO), or Filehandle is a pipe. The same as Perl L<-p|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is a named pipe (FIFO), or Filehandle is a pipe, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-p|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 r
 
 C<static method r : int ($file : string);>
 
-File is readable by effective uid/gid. The same as Perl L<-r|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is readable by effective uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-r|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 s
 
 C<static method s : long ($file : string);>
 
-File has nonzero size (returns size in bytes). The same as Perl L<-s|https://perldoc.perl.org/functions/-X>.
+If the file $file has nonzero size, returns its size in bytes, otherwise returns 0.
+
+This method corresponds to Perl's  L<-s|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
+
+The exceptions thrown by he L</"stat"> method could be thrown.
 
 =head2 u
 
 C<static method u : int ($file : string);>
 
-File has setuid bit set. The same as Perl L<-u|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file has setuid bit set, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-u|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 w
 
 C<static method w : int ($file : string);>
 
-File is writable by effective uid/gid. The same as Perl L<-u|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is writable by effective uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-u|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 x
 
 C<static method x : int ($file : string);>
 
-File is executable by effective uid/gid. The same as Perl L<-x|https://perldoc.perl.org/functions/-X>.
+If If the file doesn't exist or can't be examined(These checks are done by the L</"stat"> method), returns 0 and L<errno|SPVM::Errno/"errno"> is set to a positive value.
+
+Otherwise if the file $file is executable by effective uid/gid, returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-x|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
 
 =head2 z
 
 C<static method z : int ($file : string);>
 
-File has zero size (is empty). The same as Perl L<-z|https://perldoc.perl.org/functions/-X>.
+If the file $file has zero size (is empty), returns 1, otherwise returns 0.
+
+This method corresponds to Perl's  L<-z|https://perldoc.perl.org/functions/-X>.
+
+Exceptions:
+
+$file must be defined. Otherwise an exception is thrown.
+
+The exceptions thrown by he L</"stat"> method could be thrown.
 
 =head2 time
 
@@ -743,19 +957,49 @@ Calls the L<stderr|SPVM::Sys::IO/"spvm_stderr"> method in the L<Sys::IO|SPVM::Sy
 
 C<static method signal : void ($signum : int, $handler_name : string);>
 
-If $handler_name is "DEFAULT", $handler is set to the return value of the L<"SIG_DFL"|SPVM::Sys::Signal/"SIG_DFL"> method.
+Sets a signal handler with its name $handler_name for the given signal number $signum.
 
-If $handler_name is "IGNORE", $handler is set to the return value of the L<"SIG_IGN"|SPVM::Sys::Signal/"SIG_IGN"> method.
+If $handler_name is "DEFAULT", the signal handler is L<"SIG_DFL"|SPVM::Sys::Signal/"SIG_DFL">.
 
-And calls the L<signal|SPVM::Sys::Signal/"signal"> method in the L<Sys::Signal|SPVM::Sys::Signal> class.
+If $handler_name is "IGNORE", the signal handler is L<"SIG_IGN"|SPVM::Sys::Signal/"SIG_IGN">.
+
+See the L<signal|SPVM::Sys::Signal/"signal"> method in the Sys::Signal class in detail.
+
+Exceptions:
+
+If $handler_name is not available, an exception is thrown.
+
+The exceptions thrown by the L<signal|SPVM::Sys::Signal/"signal"> method in the Sys::Signal class could be thrown.
 
 =head2 kill
 
 C<static method kill : void ($sig : int, $pid : int);>
 
-Calls the L<kill|SPVM::Sys::Signal/"kill"> method in the L<Sys::Signal|SPVM::Sys::Signal> class.
+Send a signal $sig to the process whose process ID is $pid.
 
-If succeed, returns 1.
+See the L<kill|SPVM::Sys::Signal/"kill"> method in the Sys::Signal class in detail.
+
+In Windows, see the L<raise|SPVM::Sys::Signal/"raise"> method in the Sys::Signal class in detail.
+
+Exceptions:
+
+The exceptions thrown by the L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sys::Signal class could be thrown.
+
+The exceptions thrown by the L<raise|SPVM::Sys::Signal/"raise"> method in the Sys::Signal class could be thrown.
+
+$pid must be equal to Sys->process_id in Windows. Otherwise an exception is thrown.
+
+=head2 alarm
+
+C<static method alarm : int ($seconds : int);>
+
+Sets a alarm signal sent after seconds $seconds.
+
+See L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sys::Signal class in detail.
+
+Exceptions:
+
+The exceptions thrown by the L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sys::Signal class could be thrown.
 
 =head2 pipe
 
@@ -777,159 +1021,133 @@ If succeed, returns 1.
 
 =head1 Modules
 
-=head2 Sys::Env
+=over 2
 
-=head4 L<Sys::Env|SPVM::Sys::Env>
+=item * L<Sys::Env|SPVM::Sys::Env>
 
-=head2 Sys::IO
+=item * L<Sys::IO|SPVM::Sys::IO>
 
-=head4 L<Sys::IO|SPVM::Sys::IO>
+=item * L<Sys::IO::Constant|SPVM::Sys::IO::Constant>
 
-=head4 L<Sys::IO::Constant|SPVM::Sys::IO::Constant>
+=item * L<Sys::Ioctl|SPVM::Sys::Ioctl>
 
-=head4 L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent>
+=item * L<Sys::Ioctl::Constant|SPVM::Sys::Ioctl::Constant>
 
-=head4 L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>
+=item * L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent>
 
-=head4 L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>
+=item * L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>
 
-=head4 L<Sys::IO::Flock|SPVM::Sys::IO::Flock>
+=item * L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>
 
-=head4 L<Sys::IO::Stat|SPVM::Sys::IO::Stat>
+=item * L<Sys::IO::Flock|SPVM::Sys::IO::Flock>
 
-=head4 L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf>
+=item * L<Sys::IO::Stat|SPVM::Sys::IO::Stat>
 
-=head2 Sys::Ioctl
+=item * L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf>
 
-=head4 L<Sys::Ioctl|SPVM::Sys::Ioctl>
+=item * L<Sys::IO::Windows|SPVM::Sys::IO::Windows>
 
-=head4 L<Sys::Ioctl::Constant|SPVM::Sys::Ioctl::Constant>
+=item * L<Sys::OS|SPVM::Sys::OS>
 
-=head2 Sys::OS
+=item * L<Sys::Poll|SPVM::Sys::Poll>
 
-=head4 L<Sys::OS|SPVM::Sys::OS>
+=item * L<Sys::Poll::Constant|SPVM::Sys::Poll::Constant>
 
-=head2 Sys::Poll
+=item * L<Sys::Poll::PollfdArray|SPVM::Sys::Poll::PollfdArray>
 
-=head4 L<Sys::Poll|SPVM::Sys::Poll>
+=item * L<Sys::Process|SPVM::Sys::Process>
 
-=head4 L<Sys::Poll::Constant|SPVM::Sys::Poll::Constant>
+=item * L<Sys::Process::Constant|SPVM::Sys::Process::Constant>
 
-=head4 L<Sys::Poll::PollfdArray|SPVM::Sys::Poll::PollfdArray>
+=item * L<Sys::Select|SPVM::Sys::Select>
 
-=head2 Sys::Process
+=item * L<Sys::Select::Constant|SPVM::Sys::Select::Constant>
 
-=head4 L<Sys::Process|SPVM::Sys::Process>
+=item * L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>
 
-=head4 L<Sys::Process::Constant|SPVM::Sys::Process::Constant>
+=item * L<Sys::Signal|SPVM::Sys::Signal>
 
-=head2 Sys::Select
+=item * L<Sys::Signal::Constant|SPVM::Sys::Signal::Constant>
 
-=head4 L<Sys::Select|SPVM::Sys::Select>
+=item * L<Sys::Signal::Handler|SPVM::Sys::Signal::Handler>
 
-=head4 L<Sys::Select::Constant|SPVM::Sys::Select::Constant>
+=item * L<Sys::Socket|SPVM::Sys::Socket>
 
-=head4 L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>
+=item * L<Sys::Socket::Addrinfo|SPVM::Sys::Socket::Addrinfo>
 
-=head2 Sys::Signal
+=item * L<Sys::Socket::AddrinfoLinkedList|SPVM::Sys::Socket::AddrinfoLinkedList>
 
-=head4 L<Sys::Signal|SPVM::Sys::Signal>
+=item * L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant>
 
-=head4 L<Sys::Signal::Constant|SPVM::Sys::Signal::Constant>
+=item * L<Sys::Socket::Errno|SPVM::Sys::Socket::Errno>
 
-=head4 L<Sys::Signal::Handler|SPVM::Sys::Signal::Handler>
+=item * L<Sys::Socket::Error|SPVM::Sys::Socket::Error>
 
-=head4 L<Sys::Signal::Handler::Default|SPVM::Sys::Signal::Handler::Default>
+=item * L<Sys::Socket::Error::InetInvalidNetworkAddress|SPVM::Sys::Socket::Error::InetInvalidNetworkAddress>
 
-=head4 L<Sys::Signal::Handler::Ignore|SPVM::Sys::Signal::Handler::Ignore>
+=item * L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr>
 
-=head4 L<Sys::Signal::Handler::Monitor|SPVM::Sys::Signal::Handler::Monitor>
+=item * L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr>
 
-=head4 L<Sys::Signal::Handler::Unknown|SPVM::Sys::Signal::Handler::Unknown>
+=item * L<Sys::Socket::In_addr_base|SPVM::Sys::Socket::In_addr_base>
 
-=head2 Sys::Socket
+=item * L<Sys::Socket::Ip_mreq|SPVM::Sys::Socket::Ip_mreq>
 
-=head4 L<Sys::Socket::Util|SPVM::Sys::Socket::Util>
+=item * L<Sys::Socket::Ip_mreq_source|SPVM::Sys::Socket::Ip_mreq_source>
 
-=head4 L<Sys::Socket|SPVM::Sys::Socket>
+=item * L<Sys::Socket::Ipv6_mreq|SPVM::Sys::Socket::Ipv6_mreq>
 
-=head4 L<Sys::Socket::Addrinfo|SPVM::Sys::Socket::Addrinfo>
+=item * L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>
 
-=head4 L<Sys::Socket::AddrinfoLinkedList|SPVM::Sys::Socket::AddrinfoLinkedList>
+=item * L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In>
 
-=head4 L<Sys::Socket::Constant|SPVM::Sys::Socket::Constant>
+=item * L<Sys::Socket::Sockaddr::In6|SPVM::Sys::Socket::Sockaddr::In6>
 
-=head4 L<Sys::Socket::Error|SPVM::Sys::Socket::Error>
+=item * L<Sys::Socket::Sockaddr::Storage|SPVM::Sys::Socket::Sockaddr::Storage>
 
-=head4 L<Sys::Socket::Error::InetInvalidNetworkAddress|SPVM::Sys::Socket::Error::InetInvalidNetworkAddress>
+=item * L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un>
 
-=head4 L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr>
+=item * L<Sys::Socket::Util|SPVM::Sys::Socket::Util>
 
-=head4 L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr>
+=item * L<Sys::Time|SPVM::Sys::Time>
 
-=head4 L<Sys::Socket::In_addr_base|SPVM::Sys::Socket::In_addr_base>
+=item * L<Sys::Time::Constant|SPVM::Sys::Time::Constant>
 
-=head4 L<Sys::Socket::Ip_mreq|SPVM::Sys::Socket::Ip_mreq>
+=item * L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval>
 
-=head4 L<Sys::Socket::Ip_mreq_source|SPVM::Sys::Socket::Ip_mreq_source>
+=item * L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>
 
-=head4 L<Sys::Socket::Ipv6_mreq|SPVM::Sys::Socket::Ipv6_mreq>
+=item * L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval>
 
-=head4 L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>
+=item * L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone>
 
-=head4 L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In>
+=item * L<Sys::Time::Tm|SPVM::Sys::Time::Tm>
 
-=head4 L<Sys::Socket::Sockaddr::In6|SPVM::Sys::Socket::Sockaddr::In6>
+=item * L<Sys::Time::Tms|SPVM::Sys::Time::Tms>
 
-=head4 L<Sys::Socket::Sockaddr::Interface|SPVM::Sys::Socket::Sockaddr::Interface>
+=item * L<Sys::User|SPVM::Sys::User>
 
-=head4 L<Sys::Socket::Sockaddr::Storage|SPVM::Sys::Socket::Sockaddr::Storage>
+=item * L<Sys::User::Group|SPVM::Sys::User::Group>
 
-=head4 L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un>
+=item * L<Sys::User::Passwd|SPVM::Sys::User::Passwd>
 
-=head2 Sys::Time
-
-=head4 L<Sys::Time|SPVM::Sys::Time>
-
-=head4 L<Sys::Time::Constant|SPVM::Sys::Time::Constant>
-
-=head4 L<Sys::Time::Itimerval|SPVM::Sys::Time::Itimerval>
-
-=head4 L<Sys::Time::Timespec|SPVM::Sys::Time::Timespec>
-
-=head4 L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval>
-
-=head4 L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone>
-
-=head4 L<Sys::Time::Tms|SPVM::Sys::Time::Tm>
-
-=head4 L<Sys::Time::Tms|SPVM::Sys::Time::Tms>
-
-=head2 Sys::User
-
-=head4 L<Sys::User|SPVM::Sys::User>
-
-=head4 L<Sys::User::Group|SPVM::Sys::User::Group>
-
-=head4 L<Sys::User::Passwd|SPVM::Sys::User::Passwd>
-
-=head2 Sys::FileTest
-
-=head4 L<Sys::FileTest|SPVM::Sys::FileTest> (Deparecated)
+=back
 
 =head1 See Also
 
-=head4 L<IO::File|SPVM::IO::File>
+=over 2
 
-=head4 L<IO::Socket|SPVM::IO::Socket>
+=item * L<IO|SPVM::IO> - File IO, Sockets
 
-=head4 L<IO::Select|SPVM::IO::Select>
+=item * L<File::Spec|SPVM::File::Spec>
 
-=head4 L<IO::Poll|SPVM::IO::Poll>
+=item * L<Cwd|SPVM::Cwd>
 
-=head4 L<File::Spec|SPVM::File::Spec>
+=back
 
-=head4 L<Cwd|SPVM::Cwd>
+=head1 Repository
+
+L<SPVM::Sys - Github|https://github.com/yuki-kimoto/SPVM-Sys>
 
 =head1 Author
 
@@ -939,10 +1157,6 @@ Yuki Kimoto(L<https://github.com/yuki-kimoto>)
 
 Gabor Szabo(L<https://github.com/szabgab>)
 
-=head1 Repository
-
-L<SPVM::Sys - Github|https://github.com/yuki-kimoto/SPVM-Sys>
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
